==> zio-aws-textract_2.13-5.19.31.4-sources.jar: zio/aws/textract/model/LendingDetection.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.textract.model.primitives.Percent
import scala.jdk.CollectionConverters._
final case class LendingDetection(
    text: Optional[String] = Optional.Absent,
    selectionStatus: Optional[zio.aws.textract.model.SelectionStatus] =
      Optional.Absent,
    geometry: Optional[zio.aws.textract.model.Geometry] = Optional.Absent,
    confidence: Optional[Percent] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.LendingDetection = {
    import LendingDetection.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.LendingDetection
      .builder()
      .optionallyWith(text.map(value => value: java.lang.String))(_.text)
      .optionallyWith(selectionStatus.map(value => value.unwrap))(
        _.selectionStatus
      )
      .optionallyWith(geometry.map(value => value.buildAwsValue()))(_.geometry)
      .optionallyWith(
        confidence.map(value => Percent.unwrap(value): java.lang.Float)
      )(_.confidence)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.LendingDetection.ReadOnly =
    zio.aws.textract.model.LendingDetection.wrap(buildAwsValue())
}
object LendingDetection {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.textract.model.LendingDetection
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.LendingDetection =
      zio.aws.textract.model.LendingDetection(
        text.map(value => value),
        selectionStatus.map(value => value),
        geometry.map(value => value.asEditable),
        confidence.map(value => value)
      )
    def text: Optional[String]
    def selectionStatus: Optional[zio.aws.textract.model.SelectionStatus]
    def geometry: Optional[zio.aws.textract.model.Geometry.ReadOnly]
    def confidence: Optional[Percent]
    def getText: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("text", text)
    def getSelectionStatus
        : ZIO[Any, AwsError, zio.aws.textract.model.SelectionStatus] =
      AwsError.unwrapOptionField("selectionStatus", selectionStatus)
    def getGeometry
        : ZIO[Any, AwsError, zio.aws.textract.model.Geometry.ReadOnly] =
      AwsError.unwrapOptionField("geometry", geometry)
    def getConfidence: ZIO[Any, AwsError, Percent] =
      AwsError.unwrapOptionField("confidence", confidence)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.LendingDetection
  ) extends zio.aws.textract.model.LendingDetection.ReadOnly {
    override val text: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.text())
      .map(value => value: String)
    override val selectionStatus
        : Optional[zio.aws.textract.model.SelectionStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.selectionStatus())
        .map(value => zio.aws.textract.model.SelectionStatus.wrap(value))
    override val geometry: Optional[zio.aws.textract.model.Geometry.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.geometry())
        .map(value => zio.aws.textract.model.Geometry.wrap(value))
    override val confidence: Optional[Percent] = zio.aws.core.internal
      .optionalFromNullable(impl.confidence())
      .map(value => zio.aws.textract.model.primitives.Percent(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.LendingDetection
  ): zio.aws.textract.model.LendingDetection.ReadOnly = new Wrapper(impl)
}

==> zio-aws-textract_3-6.20.69.2-sources.jar: zio/aws/textract/model/LendingDetection.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.textract.model.primitives.Percent
import scala.jdk.CollectionConverters.*
final case class LendingDetection(
    text: Optional[String] = Optional.Absent,
    selectionStatus: Optional[zio.aws.textract.model.SelectionStatus] =
      Optional.Absent,
    geometry: Optional[zio.aws.textract.model.Geometry] = Optional.Absent,
    confidence: Optional[Percent] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.LendingDetection = {
    import LendingDetection.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.LendingDetection
      .builder()
      .optionallyWith(text.map(value => value: java.lang.String))(_.text)
      .optionallyWith(selectionStatus.map(value => value.unwrap))(
        _.selectionStatus
      )
      .optionallyWith(geometry.map(value => value.buildAwsValue()))(_.geometry)
      .optionallyWith(
        confidence.map(value => Percent.unwrap(value): java.lang.Float)
      )(_.confidence)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.LendingDetection.ReadOnly =
    zio.aws.textract.model.LendingDetection.wrap(buildAwsValue())
}
object LendingDetection {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.textract.model.LendingDetection
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.LendingDetection =
      zio.aws.textract.model.LendingDetection(
        text.map(value => value),
        selectionStatus.map(value => value),
        geometry.map(value => value.asEditable),
        confidence.map(value => value)
      )
    def text: Optional[String]
    def selectionStatus: Optional[zio.aws.textract.model.SelectionStatus]
    def geometry: Optional[zio.aws.textract.model.Geometry.ReadOnly]
    def confidence: Optional[Percent]
    def getText: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("text", text)
    def getSelectionStatus
        : ZIO[Any, AwsError, zio.aws.textract.model.SelectionStatus] =
      AwsError.unwrapOptionField("selectionStatus", selectionStatus)
    def getGeometry
        : ZIO[Any, AwsError, zio.aws.textract.model.Geometry.ReadOnly] =
      AwsError.unwrapOptionField("geometry", geometry)
    def getConfidence: ZIO[Any, AwsError, Percent] =
      AwsError.unwrapOptionField("confidence", confidence)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.LendingDetection
  ) extends zio.aws.textract.model.LendingDetection.ReadOnly {
    override val text: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.text())
      .map(value => value: String)
    override val selectionStatus
        : Optional[zio.aws.textract.model.SelectionStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.selectionStatus())
        .map(value => zio.aws.textract.model.SelectionStatus.wrap(value))
    override val geometry: Optional[zio.aws.textract.model.Geometry.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.geometry())
        .map(value => zio.aws.textract.model.Geometry.wrap(value))
    override val confidence: Optional[Percent] = zio.aws.core.internal
      .optionalFromNullable(impl.confidence())
      .map(value => zio.aws.textract.model.primitives.Percent(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.LendingDetection
  ): zio.aws.textract.model.LendingDetection.ReadOnly = new Wrapper(impl)
}
